Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(7423)

Unified Diff: chrome/browser/translate/chrome_translate_client.h

Issue 2066483004: [Wait to be closed] [Translate] Migrate IPCs to Mojo interfaces. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Ensure TranslateCallback get run Created 4 years, 5 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/translate/chrome_translate_client.h
diff --git a/chrome/browser/translate/chrome_translate_client.h b/chrome/browser/translate/chrome_translate_client.h
index d21629528d37d60a933f0dbfb7ea2be61d748986..30a2c16f7b606b78c3e0acdd79beca54fda2fa7b 100644
--- a/chrome/browser/translate/chrome_translate_client.h
+++ b/chrome/browser/translate/chrome_translate_client.h
@@ -10,7 +10,7 @@
#include "base/macros.h"
#include "chrome/browser/ui/translate/translate_bubble_model.h"
-#include "components/translate/content/browser/content_translate_driver.h"
+#include "components/translate/content/browser/content_translate_driver_impl.h"
#include "components/translate/core/browser/translate_client.h"
#include "components/translate/core/browser/translate_step.h"
#include "components/translate/core/common/translate_errors.h"
@@ -37,7 +37,7 @@ class TranslateManager;
class ChromeTranslateClient
: public translate::TranslateClient,
- public translate::ContentTranslateDriver::Observer,
+ public translate::ContentTranslateDriverImpl::Observer,
public content::WebContentsObserver,
public content::WebContentsUserData<ChromeTranslateClient> {
public:
@@ -46,9 +46,9 @@ class ChromeTranslateClient
// Gets the LanguageState associated with the page.
translate::LanguageState& GetLanguageState();
// Returns the ContentTranslateDriver instance associated with this
// WebContents.
- translate::ContentTranslateDriver& translate_driver() {
+ translate::ContentTranslateDriverImpl& translate_driver() {
return translate_driver_;
}
@@ -71,6 +71,10 @@ class ChromeTranslateClient
std::string* source,
std::string* target);
+ static void BindContentTranslateDriver(
Anand Mistry (off Chromium) 2016/07/12 07:17:09 This deserves a comment. At the very least to be c
leonhsl(Using Gerrit) 2016/07/12 10:15:09 Acknowledged.
+ content::RenderFrameHost* render_frame_host,
+ translate::mojom::ContentTranslateDriverRequest request);
+
// Gets the associated TranslateManager.
translate::TranslateManager* GetTranslateManager();
@@ -97,7 +101,7 @@ class ChromeTranslateClient
bool IsTranslatableURL(const GURL& url) override;
void ShowReportLanguageDetectionErrorUI(const GURL& report_url) override;
- // ContentTranslateDriver::Observer implementation.
+ // ContentTranslateDriverImpl::Observer implementation.
void OnLanguageDetermined(
const translate::LanguageDetectionDetails& details) override;
void OnPageTranslated(const std::string& original_lang,
@@ -115,7 +119,7 @@ class ChromeTranslateClient
void ShowBubble(translate::TranslateStep step,
translate::TranslateErrors::Type error_type);
- translate::ContentTranslateDriver translate_driver_;
+ translate::ContentTranslateDriverImpl translate_driver_;
std::unique_ptr<translate::TranslateManager> translate_manager_;
DISALLOW_COPY_AND_ASSIGN(ChromeTranslateClient);
@@ -46,9 +46,9 @@ class ChromeTranslateClient
// Gets the LanguageState associated with the page.
translate::LanguageState& GetLanguageState();
- // Returns the ContentTranslateDriver instance associated with this
+ // Returns the ContentTranslateDriverImpl instance associated with this
// WebContents.

Powered by Google App Engine
This is Rietveld 408576698